@@ -1,11 +1,11 @@
 /* DXFImportSub.m
  * Subclass of DXFImport managing the creation of graphic objects
  *
- * Copyright (C) 1996-2005 by vhf interservice GmbH
+ * Copyright (C) 1996-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-05-01
- * modified: 2005-01-06
+ * modified: 2006-12-11 (-setBounds: 10000 limit for OpenStep only)
  *
  * This file is part of the vhf Import Library.
  *
@@ -114,6 +114,7 @@
     [g sortList];
     [g setFilled:NO];
     [g setColor:state.color];
+    [g setFillColor:[state.color copy]];	// turning to filled will fill in the same color
     [g setWidth:state.width];
     [array addObject:g];
 }
@@ -263,6 +264,7 @@
 
 /* set the bounds
  * we move the graphic to 0/0 and scale to acceptable size if necessary
+ * modified: 2006-12-11
  */
 - (void)setBounds:(NSRect)bounds
 {   int		i, l, removed = 0;
@@ -276,6 +278,7 @@
     p.x = - bounds.origin.x + MMToInternal(10.0);
     p.y = - bounds.origin.y + MMToInternal(10.0);
 
+#if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)	// OpenStep 4.2
     if ( Max(bounds.size.width, bounds.size.height) > 10000.0 )
     {
         NSRunAlertPanel(@"", DXFSIZE_STRING, OK_STRING, nil, nil);
@@ -285,6 +288,7 @@
         factor = factor / Max(bounds.size.width, bounds.size.height);
         scale = YES;
     }
+#endif
 
     for (l=0; l<(int)[layerList count]; l++)
     {   NSMutableArray	*array = [[layerList objectAtIndex:l] list];
