@@ -1,11 +1,11 @@
 /* VCurve.m
  * 2-D Bezier curve
  *
- * Copyright (C) 1996-2005 by vhf interservice GmbH
+ * Copyright (C) 1996-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-29
- * modified: 2005-09-03 (-hitControl)
+ * modified: 2006-11-24
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -636,7 +636,7 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
 #define CREATEEVENTMASK NSLeftMouseDraggedMask|NSLeftMouseDownMask|NSLeftMouseUpMask|NSPeriodicMask
 - (BOOL)create:(NSEvent *)event in:(DocView*)view
 {   NSRect	viewBounds, gridBounds, drawBounds;
-    NSPoint	start, last, gridPoint, drawPoint, lastPoint, hitPoint;
+    NSPoint	start, last, gridPoint, drawPoint, lastPoint = NSZeroPoint, hitPoint;
     id		window = [view window];
     VCurve 	*drawCurveGraphic;
     BOOL	ok = YES, dragging = NO, hitEdge = NO, p3HitEdge = NO, inTimerLoop = NO;
@@ -1786,9 +1786,9 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
 }
 
 /* created:   1995-10-21
- * modified:  
- * parameter: x, y	the angles to rotate in x/y direction (2D)
- *            p		the point we have to rotate around (3D)
+ * modified:  2006-01-16
+ * parameter: x, y  the angles to rotate in x/y direction (2D)
+ *            p     the point we have to rotate around (3D)
  * purpose:   draw the graphic rotated around p with x and y
  */
 - (void)drawAtAngle:(float)angle withCenter:(NSPoint)cp in:view
@@ -1801,7 +1801,7 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
     p[3] = vhfPointRotatedAroundCenter(p3, -angle, cp);
 
     [color set];
-    [bPath setLineWidth:0.0];
+    [bPath setLineWidth:1.0/[view scaleFactor]];
     [bPath moveToPoint:p[0]];
     [bPath curveToPoint:p[3] controlPoint1:p[1] controlPoint2:p[2]];
     [bPath stroke];
@@ -1986,7 +1986,7 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
 	if ( VHFIsDrawingToScreen() && isSelected )
         {
             [super drawKnobs:rect direct:direct scaleFactor:scaleFactor];
-            [NSBezierPath setDefaultLineWidth:0.0];
+            [NSBezierPath setDefaultLineWidth:1.0/scaleFactor];
             [NSBezierPath strokeLineFromPoint:p0 toPoint:p1];
             [NSBezierPath strokeLineFromPoint:p3 toPoint:p2];
         }
@@ -2191,25 +2191,25 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
     //	if (!cubic)
     {	knobRect.origin.x = path.pts[4] - controlsize/2.0;
         knobRect.origin.y = path.pts[5] - controlsize/2.0;
-        if (!NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
+        if (selectedKnob != 0 && selectedKnob != 1 && !NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
         {   *pt = p0;
             return YES;
         }
         knobRect.origin.x = path.pts[6] - controlsize/2.0;
         knobRect.origin.y = path.pts[7] - controlsize/2.0;
-        if (!NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
+        if (selectedKnob != 1 && selectedKnob != 0 && !NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
         {   *pt = p1;
             return YES;
         }
         knobRect.origin.x = path.pts[8] - controlsize/2.0;
         knobRect.origin.y = path.pts[9] - controlsize/2.0;
-        if (!NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
+        if (selectedKnob != 2 && selectedKnob != 3 && !NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
         {   *pt = p2;
             return YES;
         }
         knobRect.origin.x = path.pts[10] - controlsize/2.0;
         knobRect.origin.y = path.pts[11] - controlsize/2.0;
-        if (!NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
+        if (selectedKnob != 3 && selectedKnob != 2 && !NSIsEmptyRect(NSIntersectionRect(hitRect , knobRect)))
         {   *pt = p3;
             return YES;
         }
@@ -2228,6 +2228,7 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
     NSRect	knobRect;
     float	lastDist = LARGE_COORD, dist;
     BOOL	hit = NO;
+    BOOL	control = [(App*)NSApp control];
 
     *pt_num = 0; // if p0==p1 or p3==p2 we take p0 or p3 !
     knobRect.size.width = knobRect.size.height = controlsize;
@@ -2238,15 +2239,15 @@ static int intersectCurves(NSPoint pc1[4], const NSPoint pc2[4], NSPoint *points
         if ( NSPointInRect(p, knobRect) )
         {
             dist = SqrDistPoints(NSMakePoint(path.pts[i+4], path.pts[i+5]), p);
-            /* if p0==p1 or p3==p2 we take p0, p3 */
-            if ( (dist < lastDist && !(*pt_num)) || (dist <= lastDist && *pt_num) )
-            //if ( dist < lastDist )
+            /* take the control point if control and both nearly identical */
+            if ( (!control && ((dist < lastDist && !(*pt_num)) ||
+                               ((dist <= lastDist || Diff(dist, lastDist) <= 5) && *pt_num))) ||
+                 (control && (((dist <= lastDist || Diff(dist, lastDist) <= 5) && !(*pt_num)) ||
+                              (dist < lastDist && Diff(dist, lastDist) > 5 && *pt_num))) )
             {
                 lastDist = dist;
                 *pt_num = i/2;
-                //selectedKnob = (*pt_num <= 1) ? 0 : 3; // old
-                if (*pt_num == 0 || *pt_num == 3) // do not select 1 and 2 but dont deselect 1 or 3
-                    selectedKnob = *pt_num;
+                selectedKnob = *pt_num;
                 hit = YES;
                 [self setSelected:YES];
             }
