@@ -1,11 +1,11 @@
 /* messages.h
  * common project messages
  *
- * Copyright (C) 1993-2005 by vhf interservice GmbH
+ * Copyright (C) 1993-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1993-08-19
- * modified: 2005-09-25
+ * modified: 2006-07-03
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -67,12 +67,6 @@
 #define UNTITLED_STRING NSLocalizedString(@"UNTITLED", "The name of a document which the user has not yet given a name to.")
 #define CANTSAVEFILE_STRING NSLocalizedString(@"Can't save file.", NULL)
 
-#define DEMOVERSION NSLocalizedString(@"Demo Version", NULL)
-#define TRADERVERSION NSLocalizedString(@"Trader Version", NULL)
-#define LICENSEDVERSION NSLocalizedString(@"Licensed Version", NULL)
-
-#define FIRSTKEYSET NSLocalizedString(@"Automatic Hostid setting. The program will terminate now.", NULL)
-#define TIMETRAP NSLocalizedString(@"Expiration date exceeded!", NULL)
 #define CANTSTARTMODUL NSLocalizedString(@"Could not start module.", "The specified program could not be started")
 #define CANTOPENFILE_STRING NSLocalizedString(@"Could not open file.", "The user-specified file could not be opened")
 #define CANTLOADFILE_STRING NSLocalizedString(@"Could not open file\n%@.", "The user-specified file could not be opened")
@@ -82,7 +76,6 @@
 #define QUITANYWAY_STRING NSLocalizedString(@"Quit Anyway", "Choice (on a button) given to user which allows him/her to quit the application even though there are unsaved documents.")
 #define QUIT_STRING NSLocalizedString(@"Quit", "The operation of exiting the application.")
 #define	DEFAULTSTRING	"Default"
-#define NOPERMISSION_STRING NSLocalizedString(@"You are not authorized to use Cenon.", NULL)
 #define CANTWRITEFILE_STRING NSLocalizedString(@"Can't write file.", "Document could not be saved")
 #define NULLGRAPHIC_STRING NSLocalizedString(@"Graphic has zero size.", "")
 #define BAD_IMAGE @"Unable to import that image into Cenon."
@@ -94,11 +87,6 @@
 #define BAD_MARGINS NSLocalizedString(@"The margins or paper size specified are invalid.", NULL)
 #define CALCULATE_STRING NSLocalizedString(@"The contour will be calculated know! You may want to stop this operation to calculate on a later time.", NULL)
 #define CALC_STRING NSLocalizedString(@"Calculate", NULL)
-#define IDIOTMODE_STRING NSLocalizedString(@"This Operation will force a recalculation of the graphic!", NULL)
-#define TAKEAWHILE_STRING NSLocalizedString(@"This Operation can take a while!", NULL)
-#define NEEDCALC_STRING NSLocalizedString(@"Layer \"%@\" needs recalculation!", NULL)
-#define NOOUTPUT_STRING NSLocalizedString(@"No data to process!", NULL)
-#define CANTLOCATETOOLNAME_STRING NSLocalizedString(@"Couldn't locate tool name '%@' in magazine!\nYou may have removed the tool since your last session.", NULL)
 
 #define ABORT_STRING NSLocalizedString(@"Abort", "Button choice allowing user to abort")
 
@@ -109,61 +97,21 @@
 #define NAMEINUSE_STRING NSLocalizedString(@"Name '%@' allready in use!", NULL)
 #define CANTFINDLIB_STRING NSLocalizedString(@"You need to install the Cenon Library!", NULL)
 
-/* Tabs (DataPanel)
- */
-#define TABLAYER_STRING NSLocalizedString(@"Layer", NULL)
-#define TABMAGAZINE_STRING NSLocalizedString(@"Magazine", NULL)
-#define TABCONTROL_STRING NSLocalizedString(@"Control", NULL)
-#define TABPOSITIONS_STRING NSLocalizedString(@"Positions", NULL)
-#define TABIMPORT_STRING NSLocalizedString(@"Import", NULL)
-#define TABMISC_STRING NSLocalizedString(@"Misc", NULL)
-
 /* layer messages */
 #define REALLYDELETELAYER_STRING  NSLocalizedString(@"Do you really want to remove layer '%@' ?", NULL)
 #define LAYERTYPEINUSE_STRING NSLocalizedString(@"Only one layer of this kind allowed!", NULL)
 #define LAYERONLYFORRECTANGLE_STRING NSLocalizedString(@"Only a single rectangle allowed on leveling layer!", "appears, if too much elements are on leveling layer")
-#define LAYERLEVELING_STRING NSLocalizedString(@"Leveling", "The name of the leveling layer")
 #define LAYERCLIPPING_STRING NSLocalizedString(@"Clipping", "The name of the clipping layer")
-#define SIDELEAVEPICKOUT_STRING NSLocalizedString(@"This Operation will remove the fill layer attached to the Pick Out!", "Change side from Pick Out")
 #define LAYERNOTEDITABLE_STRING NSLocalizedString(@"Layer is not editable!", "User tried import on selected layer")
 
-/* position messages */
-#define POSITIONTYPEINUSE_STRING NSLocalizedString(@"Only one position for parking allowed!", NULL)
-#define POSITIONPARKING_STRING NSLocalizedString(@"Parking Position", "The name of the parking position")
-
-/* magazine messages  */
-#define REMOVEMAG_STRING NSLocalizedString(@"Do you really want to remove the current magazin?", NULL)
-#define SETMAG_STRING NSLocalizedString(@"Set Magazin: This operation will remove all tools from layers!", NULL)
-
-/* tool parameter messages */
-#define PITCHFIELD_STRING NSLocalizedString(@"Pitch (%@)", NULL)
-#define COREDIAFIELD_STRING NSLocalizedString(@"Core Diameter (%@)", NULL)
-#define OVERSHOOTFIELD_STRING NSLocalizedString(@"Overshoot (%@)", NULL)
-
-/* control messages */
-#define NOTOOLSELECTED_STRING NSLocalizedString(@"No tool selected", NULL)
-#define MEASURESURFACE_STRING NSLocalizedString(@"Automatic adjust!\nBe sure to have placed the surface sensor correctly, before pressing 'Start'.", NULL)
-//#define START_STRING NSLocalizedString(@"Start", NULL)
-
-
 /* Preferences Panel
  */
 
 /* import messages */
-#define DXFSIZE_STRING NSLocalizedString(@"DXF File extends maximum size!\nPlease increase the DXF resolution in the Preferences.", NULL)
+#define DXFSIZE_STRING NSLocalizedString(@"DXF File exceeds maximum size!\nPlease increase the DXF resolution in the Preferences.", NULL)
 #define DINLAYERNAME_STRING NSLocalizedString(@"Bore %.1f mm", NULL)
 #define DXFIMPORTOUTOFBOUNDS_STRING NSLocalizedString(@"Some Objects are exceeding drawing bounds!", NULL)
 #define IMPORTTONOTEXISTINGLAYER_STRING NSLocalizedString(@"No layer available with name/color '%@'!", NULL)
 #define CREATELAYER_STRING NSLocalizedString(@"Create Layer", NULL)
 
-
-/* xyz mesages
- */
-#define CONTINUE_STRING NSLocalizedString(@"Continue", "Button choice allowing user to continue")
-#define QUITSUBPROCESS_STRING NSLocalizedString(@"Stop work?", NULL)
-#define OUTOFRANGE_STRING NSLocalizedString(@"Graphic out of range!", NULL)
-#define CLIPOUTOFRANGE_STRING NSLocalizedString(@"Clipped graphic out of range!", NULL)
-
-#define LOGINASROOT_STRING NSLocalizedString(@"Please log in as root!", NULL)
-
 #endif // VHF_H_MESSAGES
